@@ -4,7 +4,7 @@ use warnings;
 
 {
     no strict "vars";
-    $VERSION = "1.11";
+    $VERSION = "1.12";
 }
 
 use Acme::CPANAuthors::Register (
@@ -19,9 +19,7 @@ use Acme::CPANAuthors::Register (
     'DMAKI'         => 'Daisuke Maki',
     'DMUEY'         => 'Daniel Muey',
     'DROLSKY'       => 'Dave Rolsky',
-    'ELIZABETH'     => 'Elizabeth Mattijsen',
     'ETHER'         => 'Karen Etheridge',
-    'EXODIST'       => 'Chad Granum',
     'FAYLAND'       => 'Fayland Lin',
     'FLORA'         => 'Florian Ragwitz',
     'GETTY'         => 'Torsten Raudssus',
@@ -32,9 +30,8 @@ use Acme::CPANAuthors::Register (
     'KENTNL'        => 'Kent Fredric',
     'LBROCARD'      => 'Leon Brocard',
     'LEOCHARRE'     => 'Leo Charre',
-    'LEONT'         => 'Leon Timmermans',
     'MANWAR'        => 'Mohammad S Anwar',
-    'MARCEL'        => '???',
+    'MARCEL'        => 'Marcel Gruenauer',
     'MIYAGAWA'      => 'Tatsuhiko Miyagawa',
     'MLEHMANN'      => '???',
     'MRAMBERG'      => 'Marcus Ramberg',
@@ -58,6 +55,7 @@ use Acme::CPANAuthors::Register (
     'TEAM'          => 'Tom Molesworth',
     'TOBYINK'       => 'Toby Inkster',
     'TOKUHIROM'     => '???',
+    'VVELOX'        => '???',
     'YANICK'        => 'Yanick Champoux',
     'ZOFFIX'        => 'Zoffix Znet',
 
@@ -100,59 +98,57 @@ See L<http://backpan.cpantesters.org>.
 
 =head1 THE AUTHORS
 
-   1.  1842  PERLANCAR     perlancar
+   1.  1932  PERLANCAR     perlancar
    2.  550  PSIXDISTS     Perl 6 Modules
-   3.  510  SHARYANTO     Steven Haryanto
+   3.  509  SHARYANTO     Steven Haryanto
    4.  329  TOBYINK       Toby Inkster
-   5.  313  RJBS          Ricardo SIGNES
-   6.  296  ZOFFIX        Zoffix Znet
+   5.  312  RJBS          Ricardo SIGNES
+   6.  293  ZOFFIX        Zoffix Znet
    7.  287  ADAMK         Adam Kennedy
-   8.  271  ETHER         Karen Etheridge
+   8.  279  ETHER         Karen Etheridge
    9.  252  TOKUHIROM     ???
   10.  250  JGNI          John Imrie
-  11.  245  MIYAGAWA      Tatsuhiko Miyagawa
+  11.  246  MIYAGAWA      Tatsuhiko Miyagawa
   12.  223  INGY          Ingy dot Net
   13.  221  BINGOS        Chris Williams
   14.  210  FLORA         Florian Ragwitz
-  15.  204  DAGOLDEN      David Golden
-  16.  202  PLICEASE      Graham Ollis
+  15.  206  PLICEASE      Graham Ollis
+  16.  204  DAGOLDEN      David Golden
   17.  192  SMUELLER      Steffen Mueller
   18.  189  KENTNL        Kent Fredric
-  19.  182  MARCEL        ???
-  20.  176  PEVANS        Paul Evans
+  19.  182  MARCEL        Marcel Gruenauer
+  20.  178  PEVANS        Paul Evans
   21.  172  BOBTFISH      Tomas Doran
   22.  172  DROLSKY       Dave Rolsky
-  23.  166  ELIZABETH     Elizabeth Mattijsen
-  24.  161  NUFFIN        Yuval Kogman
-  25.  157  SHLOMIF       Shlomi Fish
-  26.  154  MANWAR        Mohammad S Anwar
-  27.  148  NEILB         Neil Bowers
-  28.  146  GUGOD         Liu Kang Min
-  29.  142  RSAVAGE       Ron Savage
-  30.  142  SKIM          Michal Josef Spacek
-  31.  138  BDFOY         brian d foy
-  32.  137  DMAKI         Daisuke Maki
-  33.  134  BARBIE        Barbie
-  34.  133  FAYLAND       Fayland Lin
-  35.  125  AUTRIJUS      Audrey Tang
-  36.  124  SZABGAB       Gabor Szabo
+  23.  161  NUFFIN        Yuval Kogman
+  24.  160  SHLOMIF       Shlomi Fish
+  25.  155  MANWAR        Mohammad S Anwar
+  26.  151  NEILB         Neil Bowers
+  27.  149  GUGOD         Liu Kang Min
+  28.  142  RSAVAGE       Ron Savage
+  29.  142  SKIM          Michal Josef Spacek
+  30.  138  BDFOY         brian d foy
+  31.  137  DMAKI         Daisuke Maki
+  32.  134  BARBIE        Barbie
+  33.  133  FAYLAND       Fayland Lin
+  34.  125  AUTRIJUS      Audrey Tang
+  35.  124  SZABGAB       Gabor Szabo
+  36.  121  MRAMBERG      Marcus Ramberg
   37.  121  SIMON         Simon Cozens
-  38.  120  MRAMBERG      Marcus Ramberg
-  39.  116  SALVA         Salvador Fandino Garcia
-  40.  114  MLEHMANN      ???
-  41.  113  YANICK        Yanick Champoux
-  42.  112  DMUEY         Daniel Muey
-  43.  112  RRWO          Robert Rothenberg
-  44.  111  LBROCARD      Leon Brocard
-  45.  111  RENEEB        Renee Baecker
-  46.  108  GETTY         Torsten Raudssus
-  47.  103  JHTHORSEN     Jan Henning Thorsen
-  48.  101  LEOCHARRE     Leo Charre
-  49.  101  LEONT         Leon Timmermans
-  50.  100  EXODIST       Chad Granum
-  51.  100  TEAM          Tom Molesworth
+  38.  116  SALVA         Salvador Fandino Garcia
+  39.  115  MLEHMANN      ???
+  40.  113  DMUEY         Daniel Muey
+  41.  113  RRWO          Robert Rothenberg
+  42.  113  YANICK        Yanick Champoux
+  43.  111  LBROCARD      Leon Brocard
+  44.  111  RENEEB        Renee Baecker
+  45.  108  GETTY         Torsten Raudssus
+  46.  106  JHTHORSEN     Jan Henning Thorsen
+  47.  106  VVELOX        ???
+  48.  102  TEAM          Tom Molesworth
+  49.  101  LEOCHARRE     Leo Charre
 
-List last updated: 2019-04-15T04:53:47
+List last updated: 2019-08-11T07:18:36
 
 =head1 MAINTENANCE
 
